@@ -1,50 +1,77 @@
+'''
+Mostly functions as a big wrapper for conveniently storing a lot of our analysis methods. 
+
+Generally you can follow our pipeline but,the individual steps are pretty modular if your comfortable doing simple numpy transmutations etc.
+You could for instance use the clustering on various number of n_dimensional datasets, or pull H-bond values using 
+systems_analysis.extract_hbond_values() and use thoose in replicate maps instead of k-means cluster assignments.
+
+Its a very small module so im not going to really include routine listings and such but, I will point to some relevant functions for the work
+being done by it.
+
+See Also
+--------
+mdsa_tools.Viz.visualize_reduction : Plot PCA/UMAP embeddings.
+mdsa_tools.Data_gen_hbond.create_system_representations : Build residue–residue H-bond adjacency matrices.
+numpy.linalg.svd : Linear algebra used under the hood.
+
+'''
+
 import numpy as np
 from sklearn.metrics import silhouette_score
 from sklearn.cluster import KMeans
 import numpy as np
 import os
 from sklearn.decomposition import PCA
-from mdsa_tools.Viz import visualize_reduction
 import pandas as pd
-import matplotlib.cm as cm
 import umap
 import os
 
 class systems_analysis:
-    '''A big wrapper for conveniently storing a lot of our analysis methods
     '''
+    Parameters
+    ----------
 
+    systems_representations : list, expected=list[array_1,...,array_n-1] where each array is an np.ndarray with shape=(n_frames,n_residues,n_residues)
+        Each array should have the shape as described above, where each frame has an adjacency matrix of pairwise
+        comparisons between all residues. The only axis that can differ between arrays is the number of frames (n_frames).
+
+    frame_list : listlike, shape=(data,)
+        A list of integers representing the number of frames present in each replicate. This should be in the order
+        of which the various versions of the system, and replicates where concatenated.
+
+    Attributes
+    ----------
+
+    num_systems : int, default=len(systems_representations)
+        Since this was originally built around comparative systems analysis some of the methods work on this concept directly.
+        You can still input a single item as a tuple, similar to the way you do with np.array().
+
+    systems_representations : arraylike,default=systems_representations
+        An attribute for conveniently manipulating the inputted list of arrays. 
+
+    indexes : arraylike,default=systems_representations[0][0,0,1:]
+        Derived from ``systems_representations[0][0,0,1:]``. The arrays include index data, which introduces one extra row
+        and column. This overhead is negligible for most use cases, unless operating on extremely large datasets. The
+        design is not intended for such massive-scale applications.
+    
+        
+    Notes
+    -----
+    * Automatically converts list of arrays into a feature matrix so it’s easy to build in.
+    * Expects systems of the same size for automation. For differently sized systems, you will likely need to
+      preprocess manually.
+    * Provides a general systems perspective on molecular dynamics, so it can serve as a base for other projects.
+
+    Examples
+    --------
+    >>> sa = systems_analysis([...])
+    >>> sa.num_systems
+    3
+    '''
+    
     def __init__(self,systems_representations=None,replicate_distribution=None):
         '''
-        Parameters
-        ----------
-        systems_representations:list, expected=list[array_1,...,array_n-1] where each array is an np.ndarray with shape=(n_frames,n_residues,n_residues)
-            Each array should have the shape as described above, where each frame has an adjacency matrix of pairwise
-            comparisons between all residues. The only axis that can differ between arrays is the number of frames (n_frames).
         
-        frame_list: listlike,shape=(data,)
-            A list of integers representing the number of frames present in each replicate. This should be in the order
-            of which the various versions of the system, and replicates where concatenated.
-        
-
-        Returns
-        -------
-        None its an init
-
-        
-
-
-        Notes
-        -----
-        -automatically will convert list of arrays into a feature matrix so its easy to build it in
-        -Additionally this for now expects systems of the same size for automation, if you want to run some of the downstream tasks
-        you will most likely have to do it yourself if you are trying to analyze differently sized (in terms of frames) systems
-        -Although since really this is a more general systems perspective on molecular dynamics its a great bouncing point for any systems project you may
-        have in mind
-
-
-        Examples
-        --------
         '''
         
         self.num_systems=len(systems_representations) #this is useful later on for when we are doing system_specific operations
@@ -243,28 +270,34 @@ class systems_analysis:
         '''
         Parameters
         ----------
-        feature_matrix:np.ndarray,shape=(sum(n_frames),n_residues*n_residues) where the sum of n_frames refers to the total number of frames.
+        feature_matrix : np.ndarray,shape=(sum(n_frames),n_residues*n_residues) where the sum of n_frames refers to the total number of frames.
             Each row of the new matrix represents a flattened adjacency matrix for each frame, and the frames are stacked
             in such a way that each of the original arrays follow each other sequentially.
         
             
-        n_components:int,default=2
+        n_components : int,default=2
             The number of principal components you would like to reduce your dataset down to
         
             
-        str:outfile_path,default=os.getcwd()
+        str : outfile_path, default=os.getcwd()
             path to where you would like to save your visualization
         
-        min_dist:float,default=0.5
+        method :str, order:{'PCA','UMAP'}
+            Define which method you would like to use to perform dim-reduction. We provide two methods a linear
+            and non-linear method, Principal Components Analysis (PCA) and Uniform Manifold Approximation and Projection
+            (UMAP).
+
+        min_dist : float,default=0.5
             This is a UMAP-specific parameter. It controls how tightly UMAP is allowed to pack points together. 
             Lower values will preserve more of the local clusters in the data whereas higher values will push 
             points further apart.
 
-        n_neighbors:int,default=900
+        n_neighbors : int,default=900
             Another UMAP-specific parameter. It determines the number of neighboring points used in 
             local approximations of the manifold. Larger values result in more global structure being preserved.
  
 
+            
 
         
         Returns
@@ -489,49 +522,62 @@ class systems_analysis:
     def create_PCA_ranked_weights(self,outfile_path=None, weights=None, indexes=None):
         '''Create a ranked table of PCA feature weights for the first two principal components.
 
-        Parameters
-        ----------
+    Parameters
+    ----------
+    outfile_path : str or pathlib.Path, optional
+        Directory where outputs may be written. If ``None``, uses the current working directory.
+    weights : np.ndarray, shape = (n_components, n_features), optional
+        PCA component loadings (rows = components, columns = features). If ``None``, this
+        function calls ``reduce_systems_representations()`` to compute PCA (default n=2)
+        and uses the returned ``weights``.
+    indexes : array-like of int, optional
+        Residue indices used to label pairwise comparisons. If ``None``, uses ``self.indexes``.
+        These indices define the order used to generate upper-triangle residue–residue
+        comparison labels (e.g., "12-47").
 
-        weights : np.ndarray, shape = (n_components, featuresures)
-            PCA component loadings (rows = components, columns = features). If None, this function
-            calls `reduce_systems_representations()` to compute PCA (default n=2) and uses the
-            returned `weights`.
-        indexes : array-like of int
-            Residue indices used to label pairwise comparisons. If None, uses `self.indexes`.
-            These indices define the order used to generate upper-triangle residue–residue
-            comparison labels (e.g., "12-47").
+    Returns
+    -------
+    dataframe: pandas.DataFrame,
+        A table mapping each feature (upper-triangle residue pair) to its PCA weights and
+        magnitudes.
+        
+        
+        Columns include:
 
-        Returns
-        -------
-        pandas.DataFrame
-            A table mapping each feature (upper-triangle residue pair) to its PCA weights and
-            magnitudes. Columns:
-                - 'Comparisons'     : str, "i-j" residue pair label
-                - 'PC1_Weights'     : float, raw loading for PC1
-                - 'PC2_Weights'     : float, raw loading for PC2
-                - 'PC1_magnitude'   : float, (PC1_Weights)**2
-                - 'PC2_magnitude'   : float, (PC2_Weights)**2
-                - 'PC1_mag_norm'    : float, min–max normalized PC1_magnitude to [0,1] (within PC1)
-                - 'PC2_mag_norm'    : float, min–max normalized PC2_magnitude to [0,1] (within PC2)
+        
+        * `Comparisons`    : str   — 'i-j' residue pair label
+        * `PC1_Weights`    : float — raw loading for PC1
+        * `PC2_Weights`    : float — raw loading for PC2
+        * `PC1_magnitude`  : float — (PC1_Weights)**2
+        * `PC2_magnitude`  : float — (PC2_Weights)**2
+        * `PC1_mag_norm`   : float — min–max normalized PC1_magnitude to [0, 1] (within PC1)
+        * `PC2_mag_norm`   : float — min–max normalized PC2_magnitude to [0, 1] (within PC2)
 
-        Notes
-        -----
-        - Only the upper triangle (excluding the diagonal) of the residue–residue matrix is used,
-        so each row corresponds to a unique residue pair.
-        - “Weights” are PCA component loadings (eigenvector entries). Squaring gives a magnitude
-        that is convenient for ranking feature importance within a component (sign is discarded).
-        - The min–max normalization is performed **within each component** to [0,1] and is intended
-        for visualization/ranking. Do not compare these normalized values across different PCA
-        runs unless you control scaling consistently.
-        - This function assumes at least two components are available; it reports PC1 and PC2.
+        
+    Notes
+    -----
+    
 
-        Examples
-        --------
-        >>> sa = systems_analysis([traj_array_sys1, traj_array_sys2])
-        >>> df = sa.create_PCA_ranked_weights()
-        >>> df.head()
+    - Only the upper triangle (excluding the diagonal) of the residue–residue matrix is used,
+    so each row corresponds to a unique residue pair.
+    - “Weights” are PCA component loadings (eigenvector entries). Squaring gives a magnitude
+    that is convenient for ranking feature importance within a component (sign is discarded).
+    - The min–max normalization is performed **within each component** to [0, 1] and is intended
+    for visualization/ranking. Do not compare these normalized values across different PCA
+    runs unless you control scaling consistently.
+    - This function assumes at least two components are available; it reports PC1 and PC2.
 
-        '''
+
+    Examples
+    --------
+
+
+    >>> sa = systems_analysis([traj_array_sys1, traj_array_sys2])  # doctest: +SKIP
+    >>> df = sa.create_PCA_ranked_weights()                         # doctest: +SKIP
+    >>> df.head()                                                   # doctest: +SKIP
+
+    
+    '''
 
         if weights is None:
             _,weights,_ =self.reduce_systems_representations()
@@ -723,8 +769,6 @@ class systems_analysis:
         
         return X_pca,weights,explained_variances
 
-
-
 if __name__ == '__main__':
 
     print('testing testing 1 2 3')
